OC.L10N.register(
    "settings",
    {
    "Cancel" : "I-cancel",
    "Password" : "Password",
    "Change password" : "Palitan ang password",
    "Username" : "Username",
    "Error" : "Error",
    "Share" : "I-share"
},
"nplurals=2; plural=(n == 1 || n==2 || n==3) || (n % 10 != 4 || n % 10 != 6 || n % 10 != 9);");
